@@ -1,5 +1,5 @@
-#!/usr/bin/perl 
-#
+#!/usr/bin/perl
+
 use strict;
 use warnings;
 
@@ -9,16 +9,15 @@ use Data::Dump qw(dump);
 use Perl6::Say;
 use MIME::Base64;
 
-my $consumer_key = "";
+my $consumer_key    = "";
 my $consumer_secret = "";
 
 my $consumer = OAuth::Lite::Consumer->new(
     consumer_key    => $consumer_key,
     consumer_secret => $consumer_secret,
-    ua => LWP::UserAgent->new,
+    ua              => LWP::UserAgent->new,
 );
 
-
 say "[INPUT USERNAME]";
 my $username;
 print "> ";
@@ -35,7 +34,6 @@ while ($password = <STDIN>) {
     last;
 }
 
-
 my $res = $consumer->obtain_access_token(
     url => q{https://twitter.com/oauth/access_token},
     params => {
@@ -54,8 +52,8 @@ say "[GOT ACCESS TOKEN]";
 say "TOKEN:".$res->token->token;
 say "TOKEN-SECRET:".$res->token->secret;
 say "EXPIRES:".$res->param('x_auth_expires');
-say dump($consumer->oauth_response);
-
+say $res->param('screen_name');
+say $res->param('user_id');
 
 #my $result = $consumer->get("http://twitter.com/statuses/friends_timeline.json");
 #say ($result->decoded_content||$result->content);
